@@ -11,6 +11,8 @@
 #include "resultiterator.h"
 #include "search_core_export.h"
 
+#include <memory>
+
 class QVariant;
 
 namespace Akonadi
@@ -18,6 +20,7 @@ namespace Akonadi
 namespace Search
 {
 class Term;
+class QueryPrivate;
 
 /** Search query. */
 class AKONADI_SEARCH_CORE_EXPORT Query
@@ -29,7 +32,7 @@ public:
     ~Query();
 
     void setTerm(const Term &t);
-    Term term() const;
+    [[nodiscard]] Term term() const;
 
     /**
      * Add a type to the results of the query.
@@ -49,7 +52,7 @@ public:
     void setType(const QString &type);
     void setTypes(const QStringList &types);
 
-    QStringList types() const;
+    [[nodiscard]] QStringList types() const;
 
     /**
      * Set some text which should be used to search for Items. This
@@ -59,17 +62,17 @@ public:
      * to give the best possible results.
      */
     void setSearchString(const QString &str);
-    QString searchString() const;
+    [[nodiscard]] QString searchString() const;
 
     /**
      * Only a maximum of \p limit results will be returned.
      * By default the limit is 100000.
      */
     void setLimit(uint limit);
-    uint limit() const;
+    [[nodiscard]] uint limit() const;
 
     void setOffset(uint offset);
-    uint offset() const;
+    [[nodiscard]] uint offset() const;
 
     /**
      * Filter the results in the specified date range.
@@ -78,9 +81,9 @@ public:
      */
     void setDateFilter(int year, int month = -1, int day = -1);
 
-    int yearFilter() const;
-    int monthFilter() const;
-    int dayFilter() const;
+    [[nodiscard]] int yearFilter() const;
+    [[nodiscard]] int monthFilter() const;
+    [[nodiscard]] int dayFilter() const;
 
     enum SortingOption {
         /**
@@ -104,14 +107,14 @@ public:
     };
 
     void setSortingOption(SortingOption option);
-    SortingOption sortingOption() const;
+    [[nodiscard]] SortingOption sortingOption() const;
 
     /**
      * Sets the property that should be used for sorting. This automatically
      * set the sorting mechanism to SortProperty
      */
     void setSortingProperty(const QString &property);
-    QString sortingProperty() const;
+    [[nodiscard]] QString sortingProperty() const;
 
     /**
      * Adds a custom option which any search backend could use
@@ -123,14 +126,14 @@ public:
     void addCustomOption(const QString &option, const QVariant &value);
     void removeCustomOption(const QString &option);
     QVariant customOption(const QString &option) const;
-    QVariantMap customOptions() const;
+    [[nodiscard]] QVariantMap customOptions() const;
 
-    ResultIterator exec();
+    [[nodiscard]] ResultIterator exec();
 
-    QByteArray toJSON() const;
+    [[nodiscard]] QByteArray toJSON() const;
     static Query fromJSON(const QByteArray &arr);
 
-    QUrl toSearchUrl(const QString &title = QString());
+    [[nodiscard]] QUrl toSearchUrl(const QString &title = QString());
     static Query fromSearchUrl(const QUrl &url);
     static QString titleFromQueryUrl(const QUrl &url);
 
@@ -139,9 +142,7 @@ public:
     Query &operator=(const Query &rhs);
 
 private:
-    class Private;
-    Private *const d;
+    std::unique_ptr<QueryPrivate> const d;
 };
 }
 }
-
